.. SPDX-FileCopyrightText: 2025 Contributors to the OpenSTEF project <openstef@lfenergy.org>
..
.. SPDX-License-Identifier: MPL-2.0

.. _code_of_conduct:

Code of Conduct
===============

.. include:: ../../../.github/CODE_OF_CONDUCT.md
    :parser: myst_parser.sphinx_   
